Commit in hps-java/src/main/java/org/lcsim/hps/recon/tracking on MAIN
HPSSVTSensorSetup.java+6-51.10 -> 1.11
Lowered the expected SNR for long sensors with single-ended readout from 15.6 to 8.

hps-java/src/main/java/org/lcsim/hps/recon/tracking
HPSSVTSensorSetup.java 1.10 -> 1.11
diff -u -r1.10 -r1.11
--- HPSSVTSensorSetup.java	25 Oct 2012 22:23:49 -0000	1.10
+++ HPSSVTSensorSetup.java	31 Oct 2012 22:18:30 -0000	1.11
@@ -22,7 +22,7 @@
  * @author Mathew Graham <[log in to unmask]>
  * @author Omar Moreno   <[log in to unmask]>
  * @author Jeremy McCormick <[log in to unmask]>
- * @version $Id: HPSSVTSensorSetup.java,v 1.10 2012/10/25 22:23:49 phansson Exp $
+ * @version $Id: HPSSVTSensorSetup.java,v 1.11 2012/10/31 22:18:30 phansson Exp $
  */
 public class HPSSVTSensorSetup extends Driver {
 
@@ -39,13 +39,14 @@
     private double senseTransferEfficiency = 0.419;
     /*
      * Adding separate strip capacitance for long detectors following
      * S/N = mip_charge/(270e- + 35*C[pf/cm]*L[cm]
      * e.g. for expected S/N=16 and L=20cm -> C=0.1757pf/mm
      * This should be taken into account by the noise model -> FIX THIS.
      */
     private double longSensorLengthThreshold = 190.0; //mm
-    private double readoutLongStripCapacitanceSlope = 0.1757;  // pf/mm
-    private double senseLongStripCapacitanceSlope = 0.1757;  // pf/mm
+    private double readoutLongStripCapacitanceSlope = 0.39;  // pf/mm
+    private double senseLongStripCapacitanceSlope = 0.39;  // pf/mm
 
     
     // Set of sensors
@@ -39,13 +39,14 @@
     /*
      * Adding separate strip capacitance for long detectors following
-     * S/N = mip_charge/(270e- + 35*C[pf/cm]*L[cm]
-     * e.g. for expected S/N=16 and L=20cm -> C=0.1757pf/mm
+     * S/N = mip_charge/(270e- + 36*C[pf/cm]*L[cm]
+     * e.g. for expected S/N=16 and L=20cm -> C=0.1708pf/mm
+     * e.g. for expected S/N=8 and L=20cm -> C=0.39pf/mm
      * This should be taken into account by the noise model -> FIX THIS.
      */
CVSspam 0.2.12


Use REPLY-ALL to reply to list

To unsubscribe from the LCD-CVS list, click the following link:
https://listserv.slac.stanford.edu/cgi-bin/wa?SUBED1=LCD-CVS&A=1